/*
 * Licensed Materials - Property of IBM
 * (C) Copyright IBM Corp. 2010, 2012 All Rights Reserved
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 */
 define(["dojo/_base/declare", "dijit/form/ComboBox", "dojox/string/BidiEngine"], function(declare, combo, BidiEngine){

	var bidiEngine = new BidiEngine();
	return declare("bidi.ComboBoxVisBidi",[combo],{
		LRM: "\u200e",
		RLM: "\u200f",
	        postCreate: function(){
	            if(this.isVisualMode) {
		            var options = this.store._jsonData || this.store.data;          
		            if (options != null){
		            	var text, textDirection = (this.dir == "rtl") ? "R" : "L";
		            	if(this.store._jsonData)
		            		options = options.items;
		            	else {
		            		text = this.transformValue(this.get('value'), textDirection);
		            		this.set('value', text);
		            	}
		            	for (var k = 0; k < options.length; k++) {
		            		text = this.store._jsonData ? options[k].fullName : options[k][this.searchAttr];
					if(this.store._jsonData)
		            			options[k].fullName = this.transformValue(text, textDirection);
					else
		            			options[k][this.searchAttr] = this.transformValue(text, textDirection);
		            	}
		            }
	            }
	            this.inherited(arguments);                 
	        },
		transformValue: function (text, textDirection) {
			if (!text) return text;
			if (this.dir == "rtl")
				text = this.reverseText(text);
	
			text = this.insertMarksMarkers(text);
			return bidiEngine.bidiTransform(text,"V" + textDirection + "YNN", "I" + textDirection + "NNN");
	        },
		insertMarksMarkers: function (str) {
			var marker = (this.dir == "rtl") ? this.RLM : this.LRM;
			var indx = str.search(/\d/);
			while (indx > -1) {
				str = str.substring(0,indx) + marker + str.substring (indx, str.length);
				indx++;
				while (!isNaN(str.charAt(indx)) && indx < str.length)
					indx ++;
				var subIndx = str.substring(indx).search(/\d/);
				indx = (subIndx > -1) ? indx + subIndx : -1;
			}
			return str;
		},
	        reverseText: function(text){ 
	            var temp = "";
	            var len = text.length;            
	            for(var i = 0;i < len;i++)  {
	                symbol = text.charAt(len - i - 1);
	                temp += symbol;
	            }	            
	            return temp;           
	        },
	    	_startSearch: function(key){
			if(this.isVisualMode && key.length > 1) {
		            	key = this.insertMarksMarkers(key);
			}
			this.inherited(arguments);
	    	}
	});
});	
	
