/*
 * Licensed Materials - Property of IBM
 * (C) Copyright IBM Corp. 2010, 2012 All Rights Reserved
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 */
define(["dojo/_base/declare", "dijit/form/TextBox", "dijit/form/Textarea"], function(declare, textBox, textArea){

	var isIEBrowser = (navigator.userAgent.indexOf('MSIE') > -1 || navigator.appVersion.indexOf('Trident/')) > 0;
	return declare("bidi.TextBoxVisBidi", [isIEBrowser ? textArea : textBox], {

        isVisualMode: false,
        dir: 'ltr',
        postCreate: function(){
            if(this.isVisualMode) {
                this.connect(this.textbox, "onkeyup", this._onKeyUpBidi); 
                this.connect(this.textbox, "onkeydown", this._onKeyDownBidi);
                this.connect(this.textbox, "onkeypress", this._onKeyPressBidi);
                this.connect(this.textbox, "onmouseup", this._onMouseUpBidi);
                this.connect(this.textbox, "onmousedown", this._onMouseDownBidi);
                if(isRealIE) {
                    this.connect(this.textbox, "ondblclick", this._onDblClick);                  	
                    this.connect(this.textbox, "onselect", this._onSelect);
                    this.connect(this.textbox, "onmouseout", this._onMouseOutBidi);
                    this.connect(this.textbox, "oncopy", this._onCopy);
                    this.connect(this.textbox, "oncut", this._onCut);
                    this.connect(this.textbox, "onpaste", this._onPaste); 

                    this.textbox.wrap = "off";                   
                }

                if(isRealIE && !this.focusNode.cols)
                    this.focusNode.cols = 100000;
                else if(!isRealIE && this.focusNode.maxLength == -1)
                    this.focusNode.maxLength = 100000;

                this.focusNode.style.unicodeBidi = "bidi-override";                
                this.focusNode.style.direction = this.dir;
                this.focusNode.style.textAlign = (this.dir == "rtl") ? "right" : "left";                
            }
            this.inherited(arguments);
        },
       
        _onKeyUpBidi: function(event) {
            keyUp(window.event || event);
        },
        
        _onKeyDownBidi: function(event) {
            keyDown(window.event || event);
        },

        _onKeyPressBidi: function(event) {
            if(event.charCode != 0)
            	keyPress(window.event || event);
        },

        _onMouseOutBidi: function(event) {
            mouseLeave(this.focusNode);
        },

        _onMouseUpBidi: function(event) {
            mouseUp(window.event || event, this.focusNode); 
        },

       _onMouseDownBidi: function(event) {
            mouseDown(window.event || event);       	
        },

        _onCopy: function(event) {
            copyText(this.focusNode);
        },

        _onCut: function(event) {
            cutText(this.focusNode);
        },

        _onPaste: function(event) {
            pasteText(this.focusNode);
        },

        _onDblClick: function(event) {
            mouseDblClick();
        },

        _onBlur: function(event) {
            this.inherited(arguments); 
            if(!this.isVisualMode) return;
            killFocus(this.focusNode, window.event || event);
        },

        _onSelect: function(event) {
            handleSelect(window.event || event);
        },

        reverseRtlText: function(text){ 
            var len = text.length, temp = "";	
            for(var i = 0;i < len;i++)  {
                symbol = text.charAt(len - i - 1);
                symbol = this.doSymSwapping(symbol);
                temp += symbol;
            }
            return temp;           
        },

        doSymSwapping: function(symbol){
            switch(symbol)
            {
                case "(":
                    symbol = ")";
                    break;
                case ")":
                    symbol = "(";
                    break;
                case "{":
                    symbol = "}";
                    break;
                case "}":
                    symbol = "{";
                    break;
                case "[":
                    symbol = "]";
                    break;
                case "]":
                    symbol = "[";
                    break;                  
                case "<": 
                    symbol = ">";
                    break;
                case ">":
                    symbol = "<";
                    break;                              
            }
            return symbol;
        }


	});
});
